"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SUCUpdateEntriesFileID = exports.SUCUpdateEntriesFile = exports.encodeSUCUpdateEntry = exports.parseSUCUpdateEntry = void 0;
const safe_1 = require("@zwave-js/core/safe");
const consts_1 = require("../consts");
const NVMFile_1 = require("./NVMFile");
function parseSUCUpdateEntry(buffer, offset) {
    if (buffer
        .slice(offset, offset + consts_1.SUC_UPDATE_ENTRY_SIZE)
        .equals(Buffer.alloc(consts_1.SUC_UPDATE_ENTRY_SIZE, 0))) {
        return;
    }
    const nodeId = buffer[offset];
    const changeType = buffer[offset + 1];
    const { supportedCCs, controlledCCs } = (0, safe_1.parseCCList)(buffer.slice(offset + 2, offset + consts_1.SUC_UPDATE_ENTRY_SIZE));
    return {
        nodeId,
        changeType,
        supportedCCs: supportedCCs.filter((cc) => cc > 0),
        controlledCCs: controlledCCs.filter((cc) => cc > 0),
    };
}
exports.parseSUCUpdateEntry = parseSUCUpdateEntry;
function encodeSUCUpdateEntry(entry) {
    const ret = Buffer.alloc(consts_1.SUC_UPDATE_ENTRY_SIZE, 0);
    if (entry) {
        ret[0] = entry.nodeId;
        ret[1] = entry.changeType;
        const ccList = (0, safe_1.encodeCCList)(entry.supportedCCs, entry.controlledCCs);
        if (ccList.length > consts_1.SUC_UPDATE_NODEPARM_MAX) {
            throw new safe_1.ZWaveError("Cannot encode SUC update entry, too many CCs", safe_1.ZWaveErrorCodes.Argument_Invalid);
        }
        ccList.copy(ret, 2);
    }
    return ret;
}
exports.encodeSUCUpdateEntry = encodeSUCUpdateEntry;
let SUCUpdateEntriesFile = class SUCUpdateEntriesFile extends NVMFile_1.NVMFile {
    constructor(options) {
        super(options);
        if ((0, NVMFile_1.gotDeserializationOptions)(options)) {
            this.updateEntries = [];
            for (let entry = 0; entry < consts_1.SUC_MAX_UPDATES; entry++) {
                const offset = entry * consts_1.SUC_UPDATE_ENTRY_SIZE;
                const updateEntry = parseSUCUpdateEntry(this.payload, offset);
                if (updateEntry)
                    this.updateEntries.push(updateEntry);
            }
        }
        else {
            this.updateEntries = options.updateEntries;
        }
    }
    serialize() {
        this.payload = Buffer.alloc(consts_1.SUC_MAX_UPDATES * consts_1.SUC_UPDATE_ENTRY_SIZE, 0);
        for (let i = 0; i < this.updateEntries.length; i++) {
            const offset = i * consts_1.SUC_UPDATE_ENTRY_SIZE;
            const entry = this.updateEntries[i];
            encodeSUCUpdateEntry(entry).copy(this.payload, offset);
        }
        return super.serialize();
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    toJSON() {
        return {
            ...super.toJSON(),
            "SUC update entries": this.updateEntries,
        };
    }
};
SUCUpdateEntriesFile = __decorate([
    (0, NVMFile_1.nvmFileID)(0x50003)
], SUCUpdateEntriesFile);
exports.SUCUpdateEntriesFile = SUCUpdateEntriesFile;
exports.SUCUpdateEntriesFileID = (0, NVMFile_1.getNVMFileIDStatic)(SUCUpdateEntriesFile);
//# sourceMappingURL=SUCUpdateEntriesFile.js.map